@@ -15,7 +15,8 @@ impl<'de> serde::Deserialize<'de> for Version {
 impl serde::Serialize for Version {
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
     where
-        S: serde::Serializer {
+        S: serde::Serializer,
+    {
         serializer.collect_str(self)
     }
 }
